@@ -610,6 +610,77 @@ SILE.hyphenator.languages["tr"].patterns =
 -- a couple of consonant-clusters
 "tu4r4k",
 "m1t4rak",
+-- See https://github.com/sile-typesetter/sile/issues/355
+-- Allow hyphenation to apply before apostrophes (before per pattern rules but
+-- will be substututed later, allowing after breaks minright), but work around
+-- minleft not being applied mid-word by excluding all possible single letter
+-- candidates before apostrophes.
+"1'2",
+"1’2",
+"4a1'",
+"4a1’",
+"4â1'",
+"4â1’",
+"4b1'",
+"4b1’",
+"4c1'",
+"4c1’",
+"4ç1'",
+"4ç1’",
+"4d1'",
+"4d1’",
+"4e1'",
+"4e1’",
+"4f1'",
+"4f1’",
+"4g1'",
+"4g1’",
+"4ğ1'",
+"4ğ1’",
+"4h1'",
+"4h1’",
+"4j1'",
+"4j1’",
+"4k1'",
+"4k1’",
+"4ı1'",
+"4ı1’",
+"4i1'",
+"4i1’",
+"4î1'",
+"4î1’",
+"4l1'",
+"4l1’",
+"4m1'",
+"4m1’",
+"4n1'",
+"4n1’",
+"4o1'",
+"4o1’",
+"4ö1'",
+"4ö1’",
+"4p1'",
+"4p1’",
+"4r1'",
+"4r1’",
+"4s1'",
+"4s1’",
+"4ş1'",
+"4ş1’",
+"4t1'",
+"4t1’",
+"4u1'",
+"4u1’",
+"4ü1'",
+"4ü1’",
+"4û1'",
+"4û1’",
+"4v1'",
+"4v1’",
+"4y1'",
+"4y1’",
+"4z1'",
+"4z1’",
    }
 
 -- Internationalisation stuff
