@@ -251,7 +251,7 @@ function SILE.defaultTypesetter:typeset (text)
   if text:match("^%\r?\n$") then return end
   local pId = SILE.traceStack:pushText(text)
   for token in SU.gtoke(text, SILE.settings:get("typesetter.parseppattern")) do
-    if (token.separator) then
+    if token.separator then
       self:endline()
     else
       self:setpar(token.string)
@@ -649,7 +649,7 @@ function SILE.defaultTypesetter:breakpointsToLines (breakpoints)
 
   for i = 1, #breakpoints do
     local point = breakpoints[i]
-    if not(point.position == 0) then
+    if point.position ~= 0 then
       local slice = {}
       local seenHbox = 0
       -- local toss = 1
